<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       bwap.ch
 * @since      1.0.0
 *
 * @package    Publimmo_Queue
 * @subpackage Publimmo_Queue/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Publimmo_Queue
 * @subpackage Publimmo_Queue/admin
 * @author     Alan Pilloud <alan@bwap.ch>
 */
class Publimmo_Queue_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Publimmo_Queue_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Publimmo_Queue_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/publimmo-queue-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register menus for the admin area
	 *
	 * @since    1.0.0
	 */
        public function add_menu() {
            add_options_page('Queue', 'Queue', 'manage_options', 'publimmo-queue', [$this, 'tmpl_queue']);
        }

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Publimmo_Queue_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Publimmo_Queue_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/publimmo-queue-admin.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Send data to template
	 *
	 * @since    1.0.0
	 */
        public function tmpl_queue() {
            global $wpdb;
            $this->entries = $wpdb->get_results("SELECT * FROM $wpdb->queue ORDER BY done DESC, id DESC");
            //$this->do_queue();
            include 'partials/publimmo-queue-admin-display.php';
        }

        public function do_queue() {
            global $wpdb;
            $entries = $wpdb->get_results("SELECT * FROM $wpdb->queue WHERE done = 0 ORDER BY retries DESC, id DESC");

            if (empty($entries)) {
                return false;
            }

            foreach ($entries as $entry) {
                $this->{'process_'.$entry->message_key}($entry);
            }

            $wpdb->query("DELETE FROM $wpdb->queue WHERE done = 1 AND time < date_sub(now(), INTERVAL 1 MONTH)");
        }

        public function process_send_mail($entry) {
            global $wpdb;

            $message = json_decode($entry->message_value);

            if (!$message) {
                $wpdb->update($wpdb->queue, ['retries' => $entry->retries + 1], ['ID' => $entry->id]);
                return;
            }

            $mail_sent = wp_mail($message->sendTo, $message->subject, stripslashes($message->message), $message->headers);

            if ($mail_sent) {
                $wpdb->update($wpdb->queue, ['done' => 1, 'time_sent' => date('Y-m-d h:i:s')], ['ID' => $entry->id]);
            } else {
                $wpdb->update($wpdb->queue, ['retries' => $entry->retries + 1], ['ID' => $entry->id]);
            }
        }

}
