<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              bwap.ch
 * @since             1.0.0
 * @package           Publimmo_Queue
 *
 * @wordpress-plugin
 * Plugin Name:       Queue Publimmo
 * Plugin URI:        https://valdev.ch
 * Description:       Allow to send emails with the puglin "Publimmo API connecting"
 * Version:           1.0.0
 * Author:            Valdev
 * Author URI:        https://valdev.ch
 * Text Domain:       publimmo-queue
 * Domain Path:       /languages
 * Network: True
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'PLUGIN_NAME_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-publimmo-queue-activator.php
 */
function activate_publimmo_queue() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-publimmo-queue-activator.php';
	Publimmo_Queue_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-publimmo-queue-deactivator.php
 */
function deactivate_publimmo_queue() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-publimmo-queue-deactivator.php';
	Publimmo_Queue_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_publimmo_queue' );
register_deactivation_hook( __FILE__, 'deactivate_publimmo_queue' );

add_filter('cron_schedules', function ($schedules){
    if(!isset($schedules["5min"])){
        $schedules["5min"] = array(
            'interval' => 5*60,
            'display' => __('Once every 5 minutes'));
    }
    if(!isset($schedules["30min"])){
        $schedules["30min"] = array(
            'interval' => 30*60,
            'display' => __('Once every 30 minutes'));
    }
    return $schedules;
});


/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-publimmo-queue.php';
require plugin_dir_path( __FILE__ ) . 'Api.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_publimmo_queue() {

	$plugin = new Publimmo_Queue();
	$plugin->run();

}
run_publimmo_queue();
